@@ -5,13 +5,19 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base';
 
+# INHERITS
+
 base 'Venus::Kind::Value';
 
 use Venus::True;
 use Venus::False;
 
+# STATE
+
 state $true = Venus::True->value;
 state $true_ref = \$true;
 state $true_type = 'true';
@@ -20,6 +26,8 @@ state $false = Venus::False->value;
 state $false_ref = \$false;
 state $false_type = 'false';
 
+# OVERLOADS
+
 use overload (
   '!' => sub{$_[0]->get ? $false : $true},
   '<' => sub{!!$_[0] < !!$_[1] ? $true : $false},
@@ -73,16 +81,6 @@ sub build_self {
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assert = $self->SUPER::assertion;
-
-  $assert->clear->expression('boolean');
-
-  return $assert;
-}
-
 sub comparer {
   my ($self) = @_;
 
@@ -2048,6 +2046,58 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Boolean)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Boolean;
+
+  my $new = Venus::Boolean->new;
+
+  # bless(..., "Venus::Boolean")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Boolean;
+
+  my $new = Venus::Boolean->new(1);
+
+  # bless(..., "Venus::Boolean")
+
+=back
+
+=over 4
+
+=item new example 3
+
+  package main;
+
+  use Venus::Boolean;
+
+  my $new = Venus::Boolean->new(value => 1);
+
+  # bless(..., "Venus::Boolean")
+
+=back
+
+=cut
+
 =head2 numified
 
   numified() (number)
