@@ -5,7 +5,7 @@ use 5.018;
 use strict;
 use warnings;
 
-# IMPORT
+# IMPORTS
 
 sub import {
   my ($self, @args) = @_;
@@ -25,6 +25,7 @@ sub import {
     base
     false
     from
+    mask
     mixin
     role
     test
@@ -37,9 +38,18 @@ sub import {
   if ($exports{"attr"} && !*{"${from}::attr"}{"CODE"}) {
     *{"${from}::attr"} = sub {@_ = ($from, @_); goto \&attr};
   }
+  if ($exports{"after"} && !*{"${from}::after"}{"CODE"}) {
+    *{"${from}::after"} = sub ($$) {require Venus; goto \&Venus::after};
+  }
+  if ($exports{"around"} && !*{"${from}::around"}{"CODE"}) {
+    *{"${from}::around"} = sub ($$) {require Venus; goto \&Venus::around};
+  }
   if ($exports{"base"} && !*{"${from}::base"}{"CODE"}) {
     *{"${from}::base"} = sub {@_ = ($from, @_); goto \&base};
   }
+  if ($exports{"before"} && !*{"${from}::before"}{"CODE"}) {
+    *{"${from}::before"} = sub ($$) {require Venus; goto \&Venus::before};
+  }
   if ($exports{"catch"} && !*{"${from}::catch"}{"CODE"}) {
     *{"${from}::catch"} = sub (&) {require Venus; goto \&Venus::catch};
   }
@@ -55,9 +65,18 @@ sub import {
   if ($exports{"from"} && !*{"${from}::from"}{"CODE"}) {
     *{"${from}::from"} = sub {@_ = ($from, @_); goto \&from};
   }
+  if ($exports{"handle"} && !*{"${from}::handle"}{"CODE"}) {
+    *{"${from}::handle"} = sub ($$) {require Venus; goto \&Venus::handle};
+  }
+  if ($exports{"hook"} && !*{"${from}::hook"}{"CODE"}) {
+    *{"${from}::hook"} = sub ($$$) {require Venus; goto \&Venus::hook};
+  }
   if ($exports{"raise"} && !*{"${from}::raise"}{"CODE"}) {
     *{"${from}::raise"} = sub ($;$) {require Venus; goto \&Venus::raise};
   }
+  if ($exports{"mask"} && !*{"${from}::mask"}{"CODE"}) {
+    *{"${from}::mask"} = sub {@_ = ($from, @_); goto \&mask};
+  }
   if ($exports{"mixin"} && !*{"${from}::mixin"}{"CODE"}) {
     *{"${from}::mixin"} = sub {@_ = ($from, @_); goto \&mixin};
   }
@@ -81,6 +100,8 @@ sub import {
   return $self;
 }
 
+# ROUTINES
+
 sub attr {
   my ($from, @args) = @_;
 
@@ -105,6 +126,14 @@ sub from {
   return $from;
 }
 
+sub mask {
+  my ($from, @args) = @_;
+
+  $from->MASK(@args);
+
+  return $from;
+}
+
 sub mixin {
   my ($from, @args) = @_;
 
@@ -235,6 +264,94 @@ This package provides the following functions:
 
 =cut
 
+=head2 after
+
+  after(string $name, coderef $code) (coderef)
+
+The after function installs a method modifier that executes after the original
+method, allowing you to perform actions after a method call. B<Note:> The
+return value of the modifier routine is ignored; the wrapped method always
+returns the value from the original method. Modifiers are executed in the order
+they are stacked. This function is only exported when requested.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item after example 1
+
+  package Example1;
+
+  use Venus::Class 'after', 'attr';
+
+  attr 'calls';
+
+  sub BUILD {
+    my ($self) = @_;
+    $self->calls([]);
+  }
+
+  sub test {
+    my ($self) = @_;
+    push @{$self->calls}, 'original';
+    return 'original';
+  }
+
+  after 'test', sub {
+    my ($self) = @_;
+    push @{$self->calls}, 'after';
+    return 'ignored';
+  };
+
+  package main;
+
+  my $example = Example1->new;
+  my $result = $example->test;
+
+  # "original"
+
+=back
+
+=cut
+
+=head2 around
+
+  around(string $name, coderef $code) (coderef)
+
+The around function installs a method modifier that wraps around the original
+method. The callback provided will recieve the original routine as its first
+argument. This function is only exported when requested.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item around example 1
+
+  package Example2;
+
+  use Venus::Class 'around', 'attr';
+
+  sub test {
+    my ($self, $value) = @_;
+    return $value;
+  }
+
+  around 'test', sub {
+    my ($orig, $self, $value) = @_;
+    return $self->$orig($value) * 2;
+  };
+
+  package main;
+
+  my $result = Example2->new->test(5);
+
+  # 10
+
+=back
+
+=cut
+
 =head2 attr
 
   attr(string $name) (string)
@@ -294,6 +411,57 @@ I<Since C<1.00>>
 
 =cut
 
+=head2 before
+
+  before(string $name, coderef $code) (coderef)
+
+The before function installs a method modifier that executes before the
+original method, allowing you to perform actions before a method call. B<Note:>
+The return value of the modifier routine is ignored; the wrapped method always
+returns the value from the original method. Modifiers are executed in the order
+they are stacked. This function is only exported when requested.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item before example 1
+
+  package Example3;
+
+  use Venus::Class 'attr', 'before';
+
+  attr 'calls';
+
+  sub BUILD {
+    my ($self) = @_;
+    $self->calls([]);
+  }
+
+  sub test {
+    my ($self) = @_;
+    push @{$self->calls}, 'original';
+    return $self;
+  }
+
+  before 'test', sub {
+    my ($self) = @_;
+    push @{$self->calls}, 'before';
+    return $self;
+  };
+
+  package main;
+
+  my $example = Example3->new;
+  $example->test;
+  my $calls = $example->calls;
+
+  # ['before', 'original']
+
+=back
+
+=cut
+
 =head2 catch
 
   catch(coderef $block) (Venus::Error, any)
@@ -428,6 +596,131 @@ I<Since C<1.00>>
 
 =cut
 
+=head2 handle
+
+  handle(string $name, coderef $code) (coderef)
+
+The handle function installs a method modifier that wraps a method, providing
+low-level control. The callback provided will recieve the original routine as
+its first argument (or C<undef> if the source routine doesn't exist). This
+function is only exported when requested.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item handle example 1
+
+  package Example4;
+
+  use Venus::Class 'attr', 'handle';
+
+  sub test {
+    my ($self, $value) = @_;
+    return $value;
+  }
+
+  handle 'test', sub {
+    my ($orig, $self, $value) = @_;
+    return $orig ? $self->$orig($value * 2) : 0;
+  };
+
+  package main;
+
+  my $result = Example4->new->test(5);
+
+  # 10
+
+=back
+
+=cut
+
+=head2 hook
+
+  hook(string $type, string $name, coderef $code) (coderef)
+
+The hook function installs a method modifier on a lifecycle hook method. The
+first argument is the type of modifier desired, e.g., L</before>, L</after>,
+L</around>, and the callback provided will recieve the original routine as its
+first argument. This function is only exported when requested.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item hook example 1
+
+  package Example5;
+
+  use Venus::Class 'attr', 'hook';
+
+  attr 'startup';
+
+  sub BUILD {
+    my ($self, $args) = @_;
+    $self->startup('original');
+  }
+
+  hook 'after', 'build', sub {
+    my ($self) = @_;
+    $self->startup('modified');
+  };
+
+  package main;
+
+  my $result = Example5->new->startup;
+
+  # "modified"
+
+=back
+
+=cut
+
+=head2 mask
+
+  mask(string $name) (string)
+
+The mask function creates private attribute accessors that can only be accessed
+from within the class or its subclasses. This function is exported on-demand
+unless a routine of the same name already exists.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item mask example 1
+
+  package Example;
+
+  use Venus::Class;
+
+  mask 'secret';
+
+  sub set_secret {
+    my ($self, $value) = @_;
+    $self->secret($value);
+  }
+
+  sub get_secret {
+    my ($self) = @_;
+    return $self->secret;
+  }
+
+  package main;
+
+  my $example = Example->new;
+
+  # $example->set_secret('...')
+
+  # $example->get_secret
+
+  # Exception! (if accessed externally)
+  # $example->secret
+
+=back
+
+=cut
+
 =head2 mixin
 
   mixin(string $name) (string)
