@@ -5,12 +5,18 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'attr', 'base', 'with';
 
 use Venus::Check;
 
+# INHERITS
+
 base 'Venus::Kind::Utility';
 
+# INTEGRATES
+
 with 'Venus::Role::Buildable';
 
 # ATTRIBUTES
@@ -526,6 +532,30 @@ I<Since C<3.55>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Constraint)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Constraint;
+
+  my $new = Venus::Constraint->new;
+
+  # bless(..., "Venus::Constraint")
+
+=back
+
+=cut
+
 =head2 result
 
   result(any $data) (boolean)
