@@ -5,6 +5,8 @@ use 5.018;
 use strict;
 use warnings;
 
+# OVERLOADS
+
 use overload (
   '""' => 'explain',
   'eq' => sub{$_[0]->{message} eq "$_[1]"},
@@ -25,7 +27,7 @@ sub explain {
 
   $self->trace(1) if !@{$self->frames};
 
-  my $frames = $self->{'$frames'};
+  my $frames = $self->{frames};
 
   my $file = $frames->[0][1];
   my $line = $frames->[0][2];
@@ -55,7 +57,7 @@ sub explain {
 sub frames {
   my ($self) = @_;
 
-  return $self->{'$frames'} //= [];
+  return $self->{frames} //= [];
 }
 
 sub throw {
@@ -174,6 +176,44 @@ I<Since C<1.80>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Fault)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Fault;
+
+  my $new = Venus::Fault->new;
+
+  # bless(..., "Venus::Fault")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Fault;
+
+  my $new = Venus::Fault->new('Oops!');
+
+  # bless(..., "Venus::Fault")
+
+=back
+
+=cut
+
 =head2 throw
 
   throw(string $message) (Venus::Fault)
