@@ -5,10 +5,16 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base';
 
+# INHERITS
+
 base 'Venus::Kind::Value';
 
+# OVERLOADS
+
 use overload (
   'eq' => sub{"$_[0]" eq "$_[1]"},
   'ne' => sub{"$_[0]" ne "$_[1]"},
@@ -18,16 +24,6 @@ use overload (
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assert = $self->SUPER::assertion;
-
-  $assert->clear->expression('regexp');
-
-  return $assert;
-}
-
 sub comparer {
   my ($self) = @_;
 
@@ -1682,6 +1678,58 @@ I<Since C<0.08>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Regexp)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Regexp;
+
+  my $new = Venus::Regexp->new;
+
+  # bless(..., "Venus::Regexp")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Regexp;
+
+  my $new = Venus::Regexp->new(qr/(?<greet>\w+) (?<username>\w+)/u);
+
+  # bless(..., "Venus::Regexp")
+
+=back
+
+=over 4
+
+=item new example 3
+
+  package main;
+
+  use Venus::Regexp;
+
+  my $new = Venus::Regexp->new(value => qr/(?<greet>\w+) (?<username>\w+)/u);
+
+  # bless(..., "Venus::Regexp")
+
+=back
+
+=cut
+
 =head2 numified
 
   numified() (number)
