@@ -5,10 +5,16 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base';
 
+# INHERITS
+
 base 'Venus::Kind::Value';
 
+# OVERLOADS
+
 use overload (
   'eq' => sub{$_[0]->value eq "$_[1]"},
   'ne' => sub{$_[0]->value ne "$_[1]"},
@@ -32,30 +38,6 @@ sub append_with {
   return CORE::join($delimiter // '', $data, @args);
 }
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assertion = $self->SUPER::assertion;
-
-  $assertion->match('bool')->format(sub{
-    (ref $self || $self)->new($_)
-  });
-
-  $assertion->match('float')->format(sub{
-    (ref $self || $self)->new($_)
-  });
-
-  $assertion->match('number')->format(sub{
-    (ref $self || $self)->new($_)
-  });
-
-  $assertion->match('string')->format(sub{
-    (ref $self || $self)->new($_)
-  });
-
-  return $assertion;
-}
-
 sub camelcase {
   my ($self) = @_;
 
@@ -399,6 +381,51 @@ sub uppercase {
   return CORE::uc($data);
 }
 
+sub wrap {
+  my ($self, $length, $indent) = @_;
+
+  $length ||= 80;
+
+  $indent ||= 0;
+
+  my $space = ' ' x $indent;
+
+  my $total_length = $length - CORE::length($space);
+
+  my @lines;
+
+  my @input_lines = split /\n/, $self->get;
+
+  for my $input_line (@input_lines) {
+    if ($input_line eq '') {
+      push @lines, $input_line;
+      next;
+    }
+
+    my ($saved_space) = ($input_line =~ /^(\s*)/);
+
+    $saved_space ||= '';
+
+    my @parts = split /\s+/, $input_line;
+
+    my $line = '';
+
+    for my $part (@parts) {
+      if (CORE::length($line) + CORE::length($part) + 1 > $total_length) {
+        push @lines, $space . $saved_space . $line;
+        $line = $part;
+      }
+      else {
+        $line .= $line ? " $part" : $part;
+      }
+    }
+
+    push @lines, $space . $saved_space . $line if $line;
+  }
+
+  return wantarray ? (@lines) : join "\n", @lines;
+}
+
 sub words {
   my ($self) = @_;
 
@@ -2532,6 +2559,58 @@ I<Since C<0.08>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::String)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::String;
+
+  my $new = Venus::String->new;
+
+  # bless(..., "Venus::String")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::String;
+
+  my $new = Venus::String->new('hello world');
+
+  # bless(..., "Venus::String")
+
+=back
+
+=over 4
+
+=item new example 3
+
+  package main;
+
+  use Venus::String;
+
+  my $new = Venus::String->new(value => 'hello world');
+
+  # bless(..., "Venus::String")
+
+=back
+
+=cut
+
 =head2 numified
 
   numified() (number)
@@ -3432,6 +3511,40 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 wrap
+
+  wrap(number $length, number $indent) (string)
+
+The wrap method takes a maximum character length for each line, and an optional
+number of spaces to use for indentation (defaulting to C<0>) and returns the
+text formatted as a string where each line wraps at the specified length and is
+indented with the given number of spaces. The default lenght is C<80>.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item wrap example 1
+
+  package main;
+
+  use Venus::String;
+
+  my $string = Venus::String->new(join(' ',
+    'This is an example of a long line of text that needs',
+    'to be wrapped and formatted.'
+  ));
+
+  my $wrap = $string->wrap(40, 2);
+
+  # "  This is an example of a long line of
+  #   text that needs to be wrapped and
+  #   formatted."
+
+=back
+
+=cut
+
 =head1 OPERATORS
 
 This package overloads the following operators:
